==> ansela_0.6-2.tar.gz: ansela-0.6/src/opt/anselA/filters/simple.py <==
# -*- coding: utf-8 -*-
#CPE 1704 TKS
"""
Standard Manupilation modules that are not directly UI based.
"""
from PIL import Image
from PIL import ImageDraw
from PIL import ImageEnhance
from PyQt4 import QtCore as QtCore
from PyQt4 import QtGui as QtGui 
from filters.toolbox import *
from filters.display import *
from PyQt4.QtCore import pyqtSignature

def Simple_Adjustments(self, imageToEdit, cSource, UpdateRealImage):
    if DisplayWait_Enable(self,  UpdateRealImage):
        im = imageToEdit
        Eim = Image
        if cSource =="Any":
            if self.core.valBr != 0:
                Eim =  Simple_Adjust_Br(self.core,  im)
            if self.core.valCo != 0:
                Eim =  Simple_Adjust_Co(self.core,  im)
            if self.core.valSa != 0:
                Eim = Simple_Adjust_Br(self.core,  im)
            if self.core.valSh != 0:
                Eim = Simple_Adjust_Sh(self.core,  im)
                            
        elif cSource =="Br":
            Eim =  Simple_Adjust_Br(self.core,  im)
        elif cSource =="Co":
            Eim =  Simple_Adjust_Co(self.core,  im)
        elif cSource =="Sa":
            Eim =  Simple_Adjust_Sa(self.core,  im)
        elif cSource =="Sh":
            Eim = Simple_Adjust_Sh(self.core,  im)
            
        DisplayWait_Disable(self,  UpdateRealImage,  Eim)


def Simple_Adjust_Br(core,  im):
    enhancer = ImageEnhance.Brightness(im)
    return enhancer.enhance(valToScalar(core.valBr))
    
def Simple_Adjust_Co(core,  im):
    enhancer = ImageEnhance.Contrast(im)
    return enhancer.enhance(valToScalar(core.valCo)) 
    
def Simple_Adjust_Sa(core,  im):
    enhancer = ImageEnhance.Color(im)
    return enhancer.enhance(valToScalar(core.valSa)) 
    
def Simple_Adjust_Sh(core,  im):
    enhancer = ImageEnhance.Sharpness(im)
    return enhancer.enhance(valToScalar(core.valSh)) 


@pyqtSignature("")
def TonesApply(self):
    if  (self.core.lockUpdating == False):
        self.showUpdateLabel(True)
        im = self.core.current.image
        imL = im.convert("")
        enhancer = ImageEnhance.Brightness(im)
        bright_im = enhancer.enhance(self.core.valL*-1*0.01) #any value you want
        self.photo.setPixmap(Core.pil2qpixmap(bright_im))
        self.showUpdateLabel(False)

==> ansela_0.7-5.tar.gz: ansela-0.7/src/opt/anselA/filters/simple.py <==
# -*- coding: utf-8 -*-
#CPE 1704 TKS
"""
Standard Manupilation modules that are not directly UI based.
"""
from PIL import Image
from PIL import ImageDraw
from PIL import ImageEnhance
from PyQt4 import QtCore as QtCore
from PyQt4 import QtGui as QtGui 
from core.core import *
from filters.toolbox import *
from filters.display import *
from PyQt4.QtCore import pyqtSignature

def Simple_Adjustments(self, imageToEdit, cSource, UpdateRealImage):
    if DisplayWait_Enable(self,  UpdateRealImage):
        im = imageToEdit
        Eim = None
        if cSource =="Any":
            if self.core.valBr != 0:
                Eim =  Simple_Adjust_Br(self.core,  im)
            if self.core.valCo != 0:
                Eim =  Simple_Adjust_Co(self.core,  im)
            if self.core.valSa != 0:
                Eim = Simple_Adjust_Br(self.core,  im)
            if self.core.valSh != 0:
                Eim = Simple_Adjust_Sh(self.core,  im)
                            
        elif cSource =="Br":
            Eim =  Simple_Adjust_Br(self.core,  im)
        elif cSource =="Co":
            Eim =  Simple_Adjust_Co(self.core,  im)
        elif cSource =="Sa":
            Eim =  Simple_Adjust_Sa(self.core,  im)
        elif cSource =="Sh":
            Eim = Simple_Adjust_Sh(self.core,  im)
        
        if (Eim is None):
            DisplayWait_Disable(self,  UpdateRealImage,  im)
        else:
            DisplayWait_Disable(self,  UpdateRealImage,  Eim)


def Simple_Adjust_Br(core,  im):
    enhancer = ImageEnhance.Brightness(im)
    return enhancer.enhance(valToScalar(core.valBr))
    
def Simple_Adjust_Co(core,  im):
    enhancer = ImageEnhance.Contrast(im)
    return enhancer.enhance(valToScalar(core.valCo)) 
    
def Simple_Adjust_Sa(core,  im):
    enhancer = ImageEnhance.Color(im)
    return enhancer.enhance(valToScalar(core.valSa)) 
    
def Simple_Adjust_Sh(core,  im):
    enhancer = ImageEnhance.Sharpness(im)
    return enhancer.enhance(valToScalar(core.valSh)) 


@pyqtSignature("")
def TonesApply(self):
    if  (self.core.lockUpdating == False):
        showUpdateLabel(self, True)
        im = self.core.current.image
        imL = im.convert("")
        enhancer = ImageEnhance.Brightness(im)
        bright_im = enhancer.enhance(self.core.valL*-1*0.01) #any value you want
        self.photo.setPixmap(Core.pil2qpixmap(bright_im))
        showUpdateLabel(self, False)
